Index: generic/src/mm/as.c
===================================================================
--- generic/src/mm/as.c	(revision b26db0c082ac541c4209463c1089b751d58cefde)
+++ generic/src/mm/as.c	(revision 448743faad429fa6c2d3aee5cedc3d677ca2ff1b)
@@ -526,5 +526,5 @@
 	
 	/*
 	 * Search the leaf node and the righmost record of its left sibling
 	 * to find out whether this is a miss or va belongs to an address
 	 * space area found there.
@@ -542,8 +542,8 @@
 
 	/*
 	 * Second, locate the left sibling and test its last record.
 	 * Because of its position in the B+tree, it must have base < va.
 	 */
-	if ((lnode = btree_node_left_sibling(&as->as_area_btree, leaf))) {
+	if ((lnode = btree_leaf_node_left_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) lnode->value[lnode->keys - 1];
 		spinlock_lock(&a->lock);
@@ -584,6 +584,6 @@
 	 * the number of address space areas belonging to as.
 	 * The check for conflicts is then attempted on the rightmost
 	 * record in the left sibling, the leftmost record in the right
 	 * sibling and all records in the leaf node itself.
 	 */
 	
@@ -594,5 +594,5 @@
 	
 	/* First, check the two border cases. */
-	if ((node = btree_node_left_sibling(&as->as_area_btree, leaf))) {
+	if ((node = btree_leaf_node_left_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) node->value[node->keys - 1];
 		spinlock_lock(&a->lock);
@@ -603,5 +603,5 @@
 		spinlock_unlock(&a->lock);
 	}
-	if ((node = btree_node_right_sibling(&as->as_area_btree, leaf))) {
+	if ((node = btree_leaf_node_right_neighbour(&as->as_area_btree, leaf))) {
 		a = (as_area_t *) node->value[0];
 		spinlock_lock(&a->lock);
@@ -526,5 +526,5 @@
 	
 	/*
-	 * Search the leaf node and the righmost record of its left sibling
+	 * Search the leaf node and the righmost record of its left neighbour
 	 * to find out whether this is a miss or va belongs to an address
 	 * space area found there.
@@ -542,8 +542,8 @@
 
 	/*
-	 * Second, locate the left sibling and test its last record.
+	 * Second, locate the left neighbour and test its last record.
 	 * Because of its position in the B+tree, it must have base < va.
 	 */
@@ -584,6 +584,6 @@
 	 * the number of address space areas belonging to as.
 	 * The check for conflicts is then attempted on the rightmost
-	 * record in the left sibling, the leftmost record in the right
-	 * sibling and all records in the leaf node itself.
+	 * record in the left neighbour, the leftmost record in the right
+	 * neighbour and all records in the leaf node itself.
 	 */
 	
